OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Відкриті для мене",
    "Nothing shared with you yet" : "З вами ще ніхто не поділився файлами",
    "Files and folders others share with you will show up here" : "Спільні файли та каталоги, якими поділилися з вами, з’являться тут",
    "Shared with others" : "Ви поділилися",
    "Nothing shared yet" : "Поки немає спільних ресурсів",
    "Files and folders you share will show up here" : "Файли та каталоги, якими ви поділилися, показуватимуться тут",
    "Shared by link" : "Поділилися за посиланням",
    "No shared links" : "Відсутні спільні посилання",
    "Files and folders you share by link will show up here" : "Файли та каталоги, якими ви поділилися за посиланням, показуватимуться тут",
    "Deleted shares" : "Більше недоступні",
    "No deleted shares" : "Відсутні спільні каталоги чи файли, які було вилучено",
    "Shares you deleted will show up here" : "Спільні каталоги чи файли, які ви вилучили, показуватимуться тут",
    "Pending shares" : "Запити на доступ",
    "No pending shares" : "Відсутні запити на доступ",
    "Shares you have received but not confirmed will show up here" : "Спільні дані, які ви отримали, але не підтвердили, показуватимуться тут",
    "Shares" : "Спільні",
    "No shares" : "Відсутні спільні дані",
    "Shares will show up here" : "Спільні дані показуватимуться тут",
    "Restore" : "Відновити",
    "Restore share" : "Відновити спільні дані",
    "Something happened. Unable to restore the share." : "От халепа! Неможливо відновити спільні дані.",
    "Accept share" : "Прийняти запит на спільні дані",
    "Something happened. Unable to accept the share." : "От халепа! Неможливо прийняти дані, якими поділилися з вами.",
    "Reject share" : "Відхилити запропоновані спільні дані",
    "Something happened. Unable to reject the share." : "От халепа! Неможливо відхилити дані, якими поділилися з вами.",
    "Waiting…" : "Зачекайте...",
    "error" : "помилка",
    "finished" : "завершено",
    "This will stop your current uploads." : "Ця дія призведе до зупинки поточних завантажень на сервер.",
    "Move or copy" : "Перемістити або копіювати",
    "Download" : "Звантажити",
    "Delete" : "Вилучити",
    "You can upload into this folder" : "Ви можете завантажити до цього каталогу",
    "Terms of service" : "Умови використання",
    "Show list view" : "Подання списком",
    "Show grid view" : "Подання сіткою",
    "No compatible server found at {remote}" : "Відсутній сумісний сервер за адресою {remote}",
    "Invalid server URL" : "Недійсна адреса сервера URL",
    "Failed to add the public link to your Nextcloud" : "Не вдалося додати загальнодоступне посилання до вашого Nextcloud",
    "No expiration date set" : "Не встановлено терміну дії",
    "Shared by" : "Поділилися",
    "File shares" : "Спільні файли",
    "Downloaded via public link" : "Завантажено за публічним посиланням",
    "Downloaded by {email}" : "Завантажено через {email}",
    "{file} downloaded via public link" : "{file} звантажено через публічне посилання",
    "{email} downloaded {file}" : "{email} звантажено {file}",
    "Shared with group {group}" : "Поділилися з групою {group}",
    "Removed share for group {group}" : "Вилучено спільний доступ для групи {group}",
    "{actor} shared with group {group}" : "{actor} надано доступ групі {group}",
    "{actor} removed share for group {group}" : "{actor} вилучив спільний доступ для групи {group}",
    "Share for group {group} expired" : "Термін дії спільного доступу для групи {group} сплив",
    "You shared {file} with group {group}" : "Ви поділилися {file} з групою {group}",
    "You removed group {group} from {file}" : "Ви вилучили групу {group} з {file}",
    "{actor} shared {file} with group {group}" : "{actor} надано доступ до файлу {file} з групою {group}",
    "{actor} removed group {group} from {file}" : "{actor} вилучив групи {group} з {file}",
    "Share for file {file} with group {group} expired" : "Термін дії спільного доступу до файла {file} для групи {group} вичерпано",
    "Shared as public link" : "Доступне за публічним посиланням",
    "Removed public link" : "Вилучено публічне посилання",
    "Public link expired" : "Термін дії публічного посилання вичерпано",
    "{actor} shared as public link" : "{actor} поділився публічним посиланням",
    "{actor} removed public link" : "{actor} вилучив публічне посилання",
    "Public link of {actor} expired" : "Термін дії публічного посилання {actor} вичерпано",
    "You shared {file} as public link" : "Ви поділилися {file} за допомогою публічного посилання",
    "You removed public link for {file}" : "Ви вилучили публічне посилання для файла {file}",
    "Public link expired for {file}" : "Термін дії посилання сплив для файла {file}",
    "{actor} shared {file} as public link" : "{actor} надано доступ до файлу {file} через публічне посилання",
    "{actor} removed public link for {file}" : "{actor} вилучив публічне посилання для {file}",
    "Public link of {actor} for {file} expired" : "Термін дії публічне посилання {actor} для {file} вичерпано",
    "{user} accepted the remote share" : "{user} прийняв запит на віддалений спільний ресурс",
    "{user} declined the remote share" : "{user} відхилив віддалений спільний ресурс",
    "You received a new remote share {file} from {user}" : "Ви отримали запрошення на доступ до віддаленого спільного ресурсу {file} від {user}",
    "{user} accepted the remote share of {file}" : "{user} прийняв запрошення на доступ до віддаленого спільного ресурсу {file}",
    "{user} declined the remote share of {file}" : "{user} відхилив запрошення на доступ до віддаленого спільного ресурсу {file}",
    "{user} unshared {file} from you" : "{user} закрив доступ для вас до {file}",
    "Shared with {user}" : "Надано доступ {user}",
    "Removed share for {user}" : "Скасовано спільний доступ для {user}",
    "You removed yourself" : "Ви вилучили себе",
    "{actor} removed themselves" : "{actor} вилучили себе самих",
    "{actor} shared with {user}" : "{actor} надано доступ {user}",
    "{actor} removed share for {user}" : "{actor} скасував спільний доступ для {user}",
    "Shared by {actor}" : "Поділився {actor}",
    "{actor} removed share" : "{actor} скасував спільний доступ",
    "Share for {user} expired" : "Термін дії спільного доступу для {user} вичерпано",
    "Share expired" : "Термін дії спільного доступу до ресурсу вичерпано",
    "You shared {file} with {user}" : "Ви поділилися {file} з {user}",
    "You removed {user} from {file}" : "Ви вилучили {user} з {file}",
    "You removed yourself from {file}" : "Ви вилучили себе з {file}",
    "{actor} removed themselves from {file}" : "{actor} вилучили себе з {file}",
    "{actor} shared {file} with {user}" : "{actor} надано доступ {user} до файлу {file}",
    "{actor} removed {user} from {file}" : "{actor} вилучив {user} з {file}",
    "{actor} shared {file} with you" : " {actor} поділив(ла)ся з вами доступом до файлу {file}",
    "{actor} removed you from the share named {file}" : "{actor} скасував вам доступ до спільного ресурсу {file}",
    "Share for file {file} with {user} expired" : "Термін дії доступу {user} до спільного ресурсу {file} вичерпано",
    "Share for file {file} expired" : "Термін дії спільного доступу до {file} вичерпано",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Файл або каталог, яким поділилився через ел.пошту або публічне посилання було <strong>завантажено</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Файлом або каталогом поділилися з <strong>іншого сервера</strong>",
    "Files" : "Файли",
    "A file or folder has been <strong>shared</strong>" : "Файл або каталог було відкрито для <strong>спільного доступу</strong>",
    "Shared link" : "Посилання на спільний доступ",
    "Wrong share ID, share does not exist" : "Неправильний ідентифікатор спільного ресурсу: такий ресурс відсутній",
    "Could not delete share" : "Неможливо вилучити спільний ресурс",
    "Please specify a file or folder path" : "Будь ласка, зазначте шлях до файла або каталогу",
    "Wrong path, file/folder does not exist" : "Неправильний шлях, такий файл або каталог відсутні",
    "Could not create share" : "Неможливо створити спільний ресурс",
    "Invalid permissions" : "Некоректні повноваження",
    "Please specify a valid user" : "Будь ласка, зазначте дійсного користувача",
    "Group sharing is disabled by the administrator" : "Груповий спільний доступ вимкнено адміністратором",
    "Please specify a valid group" : "Будь ласка, зазначте дійсну групу",
    "Public link sharing is disabled by the administrator" : "Адміністратор вимкнув спільний доступ за публічним посиланням",
    "Public upload disabled by the administrator" : "Публічне завантаження вимкнено адміністратором",
    "Public upload is only possible for publicly shared folders" : "Публічне завантаження можливе лише для каталогів з публічним доступом",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Виникла помилка під час надання доступу до %s, оскільки Nextcloud Talk не активний й відтак неможливо надіслати пароль.",
    "Invalid date, date format must be YYYY-MM-DD" : "Недійсна дата, формат дати має бути РРРР-ММ-ДД",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Неможливо поділитися %1$s, оскільки бекенд не дозволяє надавати доступ категорії %2$s",
    "Please specify a valid federated user ID" : "Будь ласка, зазначте дійсний федеративний ідентифікатор користувача",
    "Please specify a valid federated group ID" : "Будь ласка, зазначте дійсний федеративний ідентифікатор групи",
    "You cannot share to a Circle if the app is not enabled" : "Ви не можете поділитися у Circle, оскільки застосунок не активний",
    "Please specify a valid circle" : "Будь ласка, зазначте дійсне коло",
    "Sharing %s failed because the back end does not support room shares" : "Помилка спільного доступу %s, оскільки серверна частина не підтримує спільний доступ до кімнат",
    "Unknown share type" : "Невідомий тип спільного ресурсу",
    "Not a directory" : "Не каталог",
    "Could not lock node" : "Не вдалося заблокувати вузол",
    "Could not lock path" : "Не вдалося заблокувати шлях",
    "Wrong or no update parameter given" : "Вказано неправильний або відсутній параметр оновлення",
    "Share must at least have READ or CREATE permissions" : "Спільний доступ має щонайменше мати дозволи READ (читання) або CREATE (створення)",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Для спільного доступу потрібно щонайменше призначити дозволи READ (читання) або CREATE (створення)",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Не вдалося надіслати пароль для спільного доступу до файлу чи каталогу з використанням Nextcloud Talk, оскільки цей застосунок вимкнено.",
    "shared by %s" : "поділилися %s",
    "Download all files" : "Звантажити всі файли",
    "Direct link" : "Пряме посилання",
    "Add to your %s" : "Додайте до свого %s",
    "Share API is disabled" : "API для надання доступу вимкнено",
    "File sharing" : "Обмін файлами",
    "Share will expire tomorrow" : "Термін дії спільного доступу спливає завтра",
    "One or more of your shares will expire tomorrow" : "Термін дії одного чи кількох ваших спільних ресурсів спливає завтра",
    "Your share of {node} will expire tomorrow" : "Термін дії спільного доступу до вашого вузла {node} спливає завтра",
    "You received {share} as a share by {user}" : "(user) поділив(ла)ся з вами доступом до спільного ресурсу {share}",
    "You received {share} to group {group} as a share by {user}" : "(user) надав вам доступ до до спільного ресурсу {share} в груп {group}",
    "Accept" : "Прийняти",
    "Reject" : "Відхилити",
    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Цей застосунок дозволяє користувачам обмінюватися файлами у хмарі Nextcloud. Якщо його увімкнено, адміністратор зможе вибрати, які групи мають право ділитися файлами. Відповідні користувачі зможуть надавати доступ до файлів та каталогів іншим користувачам та групам хмари. Крім того, якщо адміністратор увімкне функцію спільного доступу через посилання, то зовнішнє посилання можна використовувати для обміну файлами з іншими користувачами поза межами хмари Nextcloud. Адміністратори також можуть встановлювати пароль, дату, до якої буде дійсний спільний доступ, дозволяти обмін файлами між серверами за допомогою посилань спільного доступу, а також можливість надавати спільний доступ з мобільних пристроїв. \nВимкнення цієї функції вилучить файли та каталоги у спільеому доступі для всіх, кому було надано доступ, доступ також зникне у клієнтах синхронізації та мобільних застосунках. Докладно можна познайомитися в документації Nextcloud.",
    "Sharing" : "Спільний доступ",
    "Accept user and group shares by default" : "Типово приймати запрошення для спільного доступу від користувачів та груп",
    "Error while toggling options" : "Помилка під час зміни параметрів",
    "Set default folder for accepted shares" : "Встановити типовий каталог для прийнятих спільних ресурсів",
    "Reset" : "Скидання",
    "Reset folder to system default" : "Відновити типові системні налаштування для каталогу",
    "Choose a default folder for accepted shares" : "Виберіть типовий каталог, куди зберігатимуться прийняті спільні ресурси",
    "Invalid path selected" : "Вибрано неправильний шлях",
    "Unknown error" : "Невідома помилка",
    "Allow editing" : "Може редагувати",
    "Read only" : "Тільки читання",
    "Allow upload and editing" : "Може завантажувати та редагувати",
    "File drop (upload only)" : "Додати файли (тільки для завантажування)",
    "Custom permissions" : "Спеціальні дозволи",
    "Read" : "Читати",
    "Upload" : "Завантажити",
    "Edit" : "Редагувати",
    "Bundled permissions" : "Збірні дозволи",
    "Allow creating" : "Може створювати",
    "Allow deleting" : "Може вилучати",
    "Allow resharing" : "Можете надавати спільний доступ",
    "Expiration date enforced" : "Вимагати термін дії",
    "Set expiration date" : "Встановити термін дії",
    "Enter a date" : "Зазначте дату",
    "Note to recipient" : "Примітка для одержувача",
    "Unshare" : "Закрити доступ",
    "group" : "група",
    "conversation" : "розмова",
    "remote" : "віддалений",
    "remote group" : "віддалена група",
    "guest" : "гість",
    "Shared with the group {user} by {owner}" : "Надав доступ групі {user} {owner}",
    "Shared with the conversation {user} by {owner}" : "{owner} поділився в чаті {user}",
    "Shared with {user} by {owner}" : "{owner} поділився з {user}",
    "Allow download" : "Дозволити звантаження",
    "Added by {initiator}" : "Додано {initiator}",
    "Via “{folder}”" : "Через “{folder}”",
    "Internal link" : "Внутрішнє посилання",
    "Copy internal link to clipboard" : "Копіювати внутрішнє посилання до буферу обміну",
    "Cannot copy, please copy the link manually" : "Неможливо скопіювати, скопіюйте посилання вручну",
    "Copy to clipboard" : "Скопіювати до буферу обміну ",
    "Only works for users with access to this folder" : "Стосується користувачів, які мають доступ до цього каталогу",
    "Only works for users with access to this file" : "Стосується користувачів, які мають доступ до цього файлу",
    "Link copied" : "Посилання скопійовано",
    "Copy public link to clipboard" : "Копіювати загальнодоступне посилання до буферу обміну",
    "Please enter the following required information before creating the share" : "Будь ласка, введіть таку інформацію перед наданням спільного доступу",
    "Password protection (enforced)" : "Захист паролем (обов'язково)",
    "Password protection" : "Password protection",
    "Enter a password" : "Зазначте пароль",
    "Expiration date (enforced)" : "Термін дії (обов'язково)",
    "Create share" : "Створити спільний ресурс",
    "Cancel" : "Скасувати",
    "Share label" : "Мітка спільного ресурсу",
    "Hide download" : "Приховати завантаження",
    "Password protect" : "Захистити паролем",
    "Password expires {passwordExpirationTime}" : "Термін дії пароля {passwordExpirationTime}",
    "Password expired" : "Термін дії пароля вичерпано",
    "Video verification" : "Відеоперевірка",
    "Enter a note for the share recipient" : "Додайте нотатку для одержувача доступу до спільного ресурсу",
    "Add another link" : "Додати інше посилання",
    "Create a new share link" : "Створити нове посилання спільного доступу",
    "{shareWith} by {initiator}" : "{shareWith} від {initiator}",
    "Shared via link by {initiator}" : "Спільний доступ через посилання від {initiator}",
    "Mail share ({label})" : "Спільний доступ через пошту ({label})",
    "Share link ({label})" : "Поділитися посиланням ({label})",
    "Share link" : "Посилання на спільний доступ",
    "Error, please enter proper password and/or expiration date" : "Помилка. Будь ласка, зазначте правильний пароль та/або термін дії",
    "No recommendations. Start typing." : "Відсутні рекомендації. Будь ласка, додайте.",
    "Resharing is not allowed" : "Надання доступу іншим не дозволяється",
    "Name or email …" : "Ім'я або електронна адреса...",
    "Name, email, or Federated Cloud ID …" : "Ім’я, адреса електронної пошти або ідентифікатор хмари…",
    "Searching …" : "Пошук...",
    "No elements found." : "Елементи не знайдено.",
    "Search globally" : "Шукати всюди",
    "on {server}" : "на {server}",
    "Others with access" : "Доступ для інших",
    "No other users with access found" : "Більше немає користувачів, які мають доступ",
    "Toggle list of others with access to this directory" : "Перемкнути подання списку інших користувачів, які мають доступ до цього каталогу",
    "Toggle list of others with access to this file" : "Перемкнути подання списку інших, які мають доступ до цього файлу",
    "Unable to fetch inherited shares" : "Неможливо отримати успадковані спільні ресурси",
    "Unable to load the shares list" : "Не вдалося завантажити список спільних ресурсів",
    "Expires {relativetime}" : "Термін дії закінчується {relativetime}",
    "this share just expired." : "термін дії спільного доступу вичерпано.",
    "Shared with you by {owner}" : "{owner} поділився з вами",
    "Link to a file" : "Посилання на файл",
    "Error creating the share: {errorMessage}" : "Помилка під час створення спільного ресурсу: {errorMessage}",
    "Error creating the share" : "Помилка під час створення спільного ресурсу",
    "Error updating the share: {errorMessage}" : "Помилка під час оновлення спільного ресурсу: {errorMessage}",
    "Error updating the share" : "Помилка оновлення спільного ресурсу",
    "Shared" : "Спільні",
    "Share" : "Спільний доступ",
    "Shared with" : "Спільний доступ з",
    "Shared with you and the group {group} by {owner}" : " {owner} надав доступ вам та групі {group}",
    "Shared with you and {circle} by {owner}" : "{owner} надав доступ вам та колу {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} надав доступ вам та у чаті {conversation}",
    "Shared with you in a conversation by {owner}" : "{owner} поділився з вами у чаті",
    "No entries found in this folder" : "Записів не знайдено в цьому каталозі",
    "Name" : "Ім’я",
    "Share time" : "Поділилися",
    "Expiration date" : "Термін дії",
    "Sorry, this link does not seem to work anymore." : "Ймовірно, що це посилання більше не дійсне.",
    "Reasons might be:" : "Можливі причини:",
    "the item was removed" : "цей ресурс було вилучено",
    "the link expired" : "термін дії посилання вичерпано",
    "sharing is disabled" : "спільний доступ заборонено",
    "For more info, please ask the person who sent this link." : "За додатковою інформацією, будь ласка, зверніться до особи, від якої ви отримали це посилання.",
    "Share note" : "Поділитися нотаткою",
    "Upload files to %s" : "Завантажувати файли до %s",
    "Note" : "Нотатка",
    "Select or drop files" : "Виберіть або перетягніть файли",
    "Uploading files" : "Завантаження файлів",
    "Uploaded files:" : "Завантажені файли:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Завантажуючи файли, ви погоджуєтеся з %1$sумовами користування%2$s.",
    "Add to your Nextcloud" : "Додати до вашої хмари Nextcloud",
    "Wrong share ID, share doesn't exist" : "Неправильний ідентифікатор спільного ресурсу, спільний ресурс відсутній",
    "Wrong path, file/folder doesn't exist" : "Неправильний шлях, файл або каталог відсутні",
    "Cannot change permissions for public share links" : "Неможливо змінити дозволи для загальнодоступних посилань",
    "Sorry, this link doesn’t seem to work anymore." : "На жаль, посилання більше не дійсне.",
    "Toggle grid view" : "Перемкнути подання сіткою"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
