<?php 
$OC_Version = array(24,0,8,2);
$OC_VersionString = '24.0.8';
$OC_Edition = '';
$OC_Channel = 'stable';
$OC_VersionCanBeUpgradedFrom = array (
  'nextcloud' => 
  array (
    '23.0' => true,
    '24.0' => true,
  ),
  'owncloud' => 
  array (
    '10.5' => true,
  ),
);
$OC_Build = '2022-12-08T12:16:03+00:00 888ffa498d3a08bb32591704806ee90075b4bc20';
$vendor = 'nextcloud';
